@@ -33,6 +33,12 @@
 
 int main(int argc, char *argv[])
 {
+    /**
+     * enable high dpi support
+     */
+    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
+
     QApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain("filelight");
@@ -85,7 +91,7 @@ int main(int argc, char *argv[])
 
         mw->show();
     }
-    else RESTORE(MainWindow);
+    else kRestoreMainWindows<MainWindow>();
 
     return app.exec();
 }
